Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type WasmModuleExpansion ¶
type WasmModuleExpansion interface{}
type WasmModuleInterface ¶
type WasmModuleInterface interface {
Create(ctx context.Context, wasmModule *wasmv1alpha1.WasmModule, opts v1.CreateOptions) (*wasmv1alpha1.WasmModule, error)
Update(ctx context.Context, wasmModule *wasmv1alpha1.WasmModule, opts v1.UpdateOptions) (*wasmv1alpha1.WasmModule, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, wasmModule *wasmv1alpha1.WasmModule, opts v1.UpdateOptions) (*wasmv1alpha1.WasmModule, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*wasmv1alpha1.WasmModule, error)
List(ctx context.Context, opts v1.ListOptions) (*wasmv1alpha1.WasmModuleList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *wasmv1alpha1.WasmModule, err error)
WasmModuleExpansion
}
WasmModuleInterface has methods to work with WasmModule resources.
type WasmModulesGetter ¶
type WasmModulesGetter interface {
WasmModules(namespace string) WasmModuleInterface
}
WasmModulesGetter has a method to return a WasmModuleInterface. A group's client should implement this interface.
type WasmV1alpha1Client ¶
type WasmV1alpha1Client struct {
// contains filtered or unexported fields
}
WasmV1alpha1Client is used to interact with features provided by the wasm.serving.knative.dev group.
func New ¶
func New(c rest.Interface) *WasmV1alpha1Client
New creates a new WasmV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*WasmV1alpha1Client, error)
NewForConfig creates a new WasmV1alpha1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new WasmV1alpha1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *WasmV1alpha1Client
NewForConfigOrDie creates a new WasmV1alpha1Client for the given config and panics if there is an error in the config.
func (*WasmV1alpha1Client) RESTClient ¶
func (c *WasmV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*WasmV1alpha1Client) WasmModules ¶
func (c *WasmV1alpha1Client) WasmModules(namespace string) WasmModuleInterface
type WasmV1alpha1Interface ¶
type WasmV1alpha1Interface interface {
RESTClient() rest.Interface
WasmModulesGetter
}