Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type WasmModuleLister ¶
type WasmModuleLister interface {
// List lists all WasmModules in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*wasmv1alpha1.WasmModule, err error)
// WasmModules returns an object that can list and get WasmModules.
WasmModules(namespace string) WasmModuleNamespaceLister
WasmModuleListerExpansion
}
WasmModuleLister helps list WasmModules. All objects returned here must be treated as read-only.
func NewWasmModuleLister ¶
func NewWasmModuleLister(indexer cache.Indexer) WasmModuleLister
NewWasmModuleLister returns a new WasmModuleLister.
type WasmModuleListerExpansion ¶
type WasmModuleListerExpansion interface{}
WasmModuleListerExpansion allows custom methods to be added to WasmModuleLister.
type WasmModuleNamespaceLister ¶
type WasmModuleNamespaceLister interface {
// List lists all WasmModules in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*wasmv1alpha1.WasmModule, err error)
// Get retrieves the WasmModule from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*wasmv1alpha1.WasmModule, error)
WasmModuleNamespaceListerExpansion
}
WasmModuleNamespaceLister helps list and get WasmModules. All objects returned here must be treated as read-only.
type WasmModuleNamespaceListerExpansion ¶
type WasmModuleNamespaceListerExpansion interface{}
WasmModuleNamespaceListerExpansion allows custom methods to be added to WasmModuleNamespaceLister.
Click to show internal directories.
Click to hide internal directories.